@@ -4,10 +4,10 @@ use Rope;
 
 extends 'One';
 
-prototyped {
+prototyped (
 	three => sub {
 		return 100;
 	}
-};
+);
 
 1;
